@@ -1,13 +1,14 @@
 from typing import List
+from typing import TYPE_CHECKING
 
+from .base import HKBaseClass
+from .common.hkRootLevelContainerNamedVariant import hkRootLevelContainerNamedVariant
 from ..binary import BinaryReader, BinaryWriter
 from ..binary.types import Int32, UInt32
 from ..container.util.globalreference import GlobalReference
 from ..container.util.localfixup import LocalFixup
-from .base import HKBaseClass
-from .common.hkRootLevelContainerNamedVariant import hkRootLevelContainerNamedVariant
 
-if False:
+if TYPE_CHECKING:
     from ..hkfile import HKFile
     from ..container.util.hkobject import HKObject
 
