@@ -1,11 +1,12 @@
 from typing import Sequence
+from typing import TYPE_CHECKING
 
-from ..binary import BinaryReader, BinaryWriter
-from ..binary.types import UInt32
 from .base import HKBaseClass
 from .common.hkpConvexShape import hkpConvexShape
+from ..binary import BinaryReader, BinaryWriter
+from ..binary.types import UInt32
 
-if False:
+if TYPE_CHECKING:
     from ..hkfile import HKFile
     from ..container.util.hkobject import HKObject
 
