@@ -10,9 +10,14 @@ def parse_args():
     parser = argparse.ArgumentParser(
         description="Convert Havok Static Compound (.hksc) to Havok Rigid Body array (.hkrb)"
     )
-    parser.add_argument("hkscFile", type=Path, help="Path to a Havok Static Compound file")
     parser.add_argument(
-        "outFile", type=Path, help="Path to the destination Havok Rigid Body file", nargs="?"
+        "hkscFile", type=Path, help="Path to a Havok Static Compound file"
+    )
+    parser.add_argument(
+        "outFile",
+        type=Path,
+        help="Path to the destination Havok Rigid Body file",
+        nargs="?",
     )
 
     return parser.parse_args()
@@ -31,17 +36,17 @@ def main():
 
     nx = hk.files[0].header.pointer_size == 8
 
-    shapes = [
-        instance.shape
-        for rigidbody in hk.files[1]
-            .data.contents[0]
-            .namedVariants[0]
-            .variant.systems[0]
-            .rigidBodies
-        for instance in rigidbody.collidable.shape.instances
-    ]
+    names = []
+    colInfos = []
+    shapes = []
 
-    shapes_to_hkrb(shapes, args.hkscFile, args.outFile, nx)
+    for rigidBody in hk.files[1].data.contents[0].namedVariants[0].variant.systems[0].rigidBodies:
+        for instance in rigidBody.collidable.shape.instances:
+            names.append(rigidBody.name)
+            colInfos.append(rigidBody.collidable.broadPhaseHandle.collisionFilterInfo)
+            shapes.append(instance.shape)
+
+    shapes_to_hkrb(names, colInfos, shapes, args.hkscFile, args.outFile, nx)
 
 
 if __name__ == "__main__":
